Type: Package
Package: neuroSCC
Title: Bridging Simultaneous Confidence Corridors and PET Neuroimaging
Version: 1.0.2
Authors@R: c(
    person("Juan A.", "Arias Lopez", , "iguanamarina@protonmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0002-3355-6393")),
    person("Virgilio", "Gomez Rubio", , "Virgilio.Gomez@uclm.es", role = "rev",
           comment = c(ORCID = "0000-0002-4791-3072")),
    person("Pablo", "Aguiar Fernandez", , "pablo.aguiar@usc.es", role = "ths",
           comment = c(ORCID = "0000-0002-7322-2195")),
    person("Andrew", "Haddon Kemp", , "A.H.Kemp@swansea.ac.uk", role = "ths",
           comment = c(ORCID = "0000-0003-1146-3791"))
  )
Maintainer: Juan A. Arias Lopez <iguanamarina@protonmail.com>
Description: Tools for the structured processing of PET neuroimaging data 
    in preparation for the estimation of Simultaneous Confidence Corridors (SCCs) 
    for one-group, two-group, or single-patient vs group comparisons. 
    The package facilitates PET image loading, data restructuring, integration 
    into a Functional Data Analysis framework, contour extraction, identification 
    of significant results, and performance evaluation. It bridges established 
    packages (e.g., 'oro.nifti') with novel statistical methodologies (e.g., 
    'ImageSCC') and enables reproducible analysis pipelines, including 
    comparison with Statistical Parametric Mapping ('SPM').
License: MIT + file LICENSE
URL: https://iguanamarina.github.io/neuroSCC/,
        https://github.com/iguanamarina/PhD-2023-SCC-vs-SPM-Group-vs-Group,
        https://github.com/iguanamarina/PhD-2024-SCC-vs-SPM-SinglePatient-vs-Group
BugReports: https://github.com/iguanamarina/neuroSCC/issues
Depends: R (>= 4.2.0)
Imports: dplyr, graphics, memisc, oro.nifti, stats, tidyr, utils
Suggests: BPST, fields, ggplot2, ImageSCC, knitr, patchwork, rcmdcheck,
        remotes, rmarkdown, roxygen2 (>= 7.1.0), scales, Triangulation,
        viridis
Additional_repositories: https://iguanamarina.github.io/neuroSCC-drat
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-04-18 08:45:46 UTC; juana
Author: Juan A. Arias Lopez [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-3355-6393>),
  Virgilio Gomez Rubio [rev] (ORCID:
    <https://orcid.org/0000-0002-4791-3072>),
  Pablo Aguiar Fernandez [ths] (ORCID:
    <https://orcid.org/0000-0002-7322-2195>),
  Andrew Haddon Kemp [ths] (ORCID:
    <https://orcid.org/0000-0003-1146-3791>)
Repository: CRAN
Date/Publication: 2026-04-18 09:00:02 UTC
Built: R 4.6.0; ; 2026-04-29 22:51:00 UTC; unix
