# Generated by roxygen2: do not edit by hand

export(calculateMetrics)
export(databaseCreator)
export(generatePoissonClones)
export(getDimensions)
export(getPoints)
export(getSPMbinary)
export(matrixCreator)
export(meanNormalization)
export(neuroCleaner)
export(neuroContour)
export(plotSCCcomparisonPanel)
export(plotSCCpanel)
export(plotValidationPanel)
export(processROIs)
importFrom(graphics,points)
importFrom(stats,rpois)
importFrom(utils,globalVariables)
